% function PicoSetup
% Input area !!!
% Set required parameters - Osciloscopes to use, Voltage ranges, Timebase and Trigger parameters

% Choose units to be used 1-'ZOR15/026', 2-'ZOR15/065', 3-'ZOR15/051'
UnitNumber = [1 3];

% Input voltage range of channels (UnitNumber, ChannelNumber)
% 50,100,200,500 mV, 1,2,5,10,20,50,100 V
% numeric value in volts which means Range
clear('ChannelVRange')

ChannelVRange(1,1) = 0.5;
ChannelVRange(1,2) = 0.5;
ChannelVRange(1,3) = 0;
ChannelVRange(1,4) = 0.5;

ChannelVRange(2,1) = 0;
ChannelVRange(2,2) = 0.5;
ChannelVRange(2,3) = 0;
ChannelVRange(2,4) = 0;

ChannelVRange(3,1) = 0.5;
ChannelVRange(3,2) = 0.5;
ChannelVRange(3,3) = 0;
ChannelVRange(3,4) = 0.5;

% Channel coefficient (transfer ratio)
ChannelRatio(1,1) = 0;
ChannelRatio(1,2) = 0;
ChannelRatio(1,3) = 0;
ChannelRatio(1,4) = 0;

ChannelRatio(2,1) = 0;
ChannelRatio(2,2) = 0;
ChannelRatio(2,3) = 0;
ChannelRatio(2,4) = 0;

ChannelRatio(3,1) = 0;
ChannelRatio(3,2) = 0;
ChannelRatio(3,3) = 0;
ChannelRatio(3,4) = 0;

% Channel desription (Legend: 'Total arc current, A)
ChannelLegend{1,1} = '';
ChannelLegend{1,2} = '';
ChannelLegend{1,3} = '';
ChannelLegend{1,4} = '';

ChannelLegend{2,1} = '';
ChannelLegend{2,2} = '';
ChannelLegend{2,3} = '';
ChannelLegend{2,4} = '';

ChannelLegend{3,1} = '';
ChannelLegend{3,2} = '';
ChannelLegend{3,3} = '';
ChannelLegend{3,4} = '';

% Input timebase=Sample interval (1=12.5ns, 2=25ns - available only with special channel use rules see manual)
% SamplePeriod can be evaluated as T = (TimeBase-1)/2e7 ns for the
% TimaBase in range 2,3,4... 2^30
TimeBase = 3;
SamplePeriod = (TimeBase-1)/2e7;
disp(strcat('SamplePeriod=',num2str(SamplePeriod),'s'));
NoOfSamples = uint32(2^18);
disp(strcat('TimeMeasured=',num2str((double(TimeBase)-1)/2e7*double(NoOfSamples)),'s'));

Trigger(1).Channel=2;
Trigger(2).Channel=2;
Trigger(3).Channel=1;

% Time between trigger event and the record start
% evaluation formula Time = Delay*8*SamplePeriod
Trigger(1).Delay=0;
Trigger(2).Delay=0;
Trigger(3).Delay=0;

% Trigger Level in 16 bit ADC count
Trigger(1).Level=0;
Trigger(2).Level=300;
Trigger(3).Level=0;

% Trigger Level in 16 bit ADC count
Trigger(1).Position=0;
Trigger(2).Position=0;
Trigger(3).Position=0;

% Trigger direction RISING=4, FALLING=6, RISING OR FALLING = 8, NONE
Trigger(1).Direction='RISING';
Trigger(2).Direction='RISING';
Trigger(3).Direction='RISING';

AutoTriggerMilliseconds = 10;

% The end of input area !!!

% Evaluation and parameters preparation area !!!

% Evaluation of channel voltage range parameter

for k = UnitNumber
    for kk = 1:4
        if ChannelVRange(k,kk)<0.01
            ChannelPRange{k,kk} = 'PS4000_10MV';
            ChannelVRange(k,kk)=0;
        elseif ChannelVRange(k,kk)<0.02
            ChannelPRange{k,kk} = 'PS4000_10MV';
            ChannelVRange(k,kk)=0.01;
        elseif ChannelVRange(k,kk)<0.05
            ChannelPRange{k,kk} = 'PS4000_20MV';
            ChannelVRange(k,kk)=0.02;
        elseif ChannelVRange(k,kk)<0.1
            ChannelPRange{k,kk} = 'PS4000_50MV';
            ChannelVRange(k,kk)=0.05;
        elseif ChannelVRange(k,kk)<0.2
            ChannelPRange{k,kk} = 'PS4000_100MV';
            ChannelVRange(k,kk)=0.1;
        elseif ChannelVRange(k,kk)<0.5
            ChannelPRange{k,kk} = 'PS4000_200MV';
            ChannelVRange(k,kk)=0.2;
        elseif ChannelVRange(k,kk)<1
            ChannelPRange{k,kk} = 'PS4000_500MV';
            ChannelVRange(k,kk)=0.5;
        elseif ChannelVRange(k,kk)<2
            ChannelPRange{k,kk} = 'PS4000_1V';
            ChannelVRange(k,kk)=1;
        elseif ChannelVRange(k,kk)<5
            ChannelPRange{k,kk} = 'PS4000_2V';
            ChannelVRange(k,kk)=2;
        elseif ChannelVRange(k,kk)<10
            ChannelPRange{k,kk} = 'PS4000_5V';
            ChannelVRange(k,kk)=5;
        elseif ChannelVRange(k,kk)<20
            ChannelPRange{k,kk} = 'PS4000_10V';
            ChannelVRange(k,kk)=10;
        elseif ChannelVRange(k,kk)<50
            ChannelPRange{k,kk} = 'PS4000_20V';
            ChannelVRange(k,kk)=20;
        elseif ChannelVRange(k,kk)<100
            ChannelPRange{k,kk} = 'PS4000_50V';
            ChannelVRange(k,kk)=50;
        else
            ChannelPRange{k,kk} = 'PS4000_100V';
            ChannelVRange(k,kk)=11;
        end
    end
end

% Preparation of channel variables
PS4000_Channel = {'PS4000_CHANNEL_A'};
PS4000_Channel{2} = 'PS4000_CHANNEL_B';
PS4000_Channel{3} = 'PS4000_CHANNEL_C';
PS4000_Channel{4} = 'PS4000_CHANNEL_D';

% Preparation of trigger properties structure

clear tTriggerConditions
clear tTriggerChannelProperties

for k = UnitNumber
    tTriggerConditions(k).channelA = int16(0);
    tTriggerConditions(k).channelB = int16(0);
    tTriggerConditions(k).channelC = int16(0);
    tTriggerConditions(k).channelD = int16(0);
    tTriggerConditions(k).external = int16(0);
    tTriggerConditions(k).aux = int16(0);
    tTriggerConditions(k).pulseWidthQualifier = int16(0);
    if Trigger(k).Channel == 1
        tTriggerConditions(k).channelA = int16(1);
    elseif Trigger(k).Channel == 2
        tTriggerConditions(k).channelB = int16(1);
    elseif Trigger(k).Channel == 3
        tTriggerConditions(k).channelC = int16(1);
    elseif Trigger(k).Channel == 4
        tTriggerConditions(k).channelD = int16(1);
    end

    tTriggerChannelProperties(k).thresholdUpper = int16(Trigger(k).Level);
    tTriggerChannelProperties(k).thresholdUpperHysteresis = uint16(10);
    tTriggerChannelProperties(k).thresholdLower = int16(Trigger(k).Level);
    tTriggerChannelProperties(k).thresholdLowerHysteresis = uint16(10);
    tTriggerChannelProperties(k).channel = PS4000_Channel{Trigger(k).Channel};
    tTriggerChannelProperties(k).thresholdMode = uint16(0);
    
end


% Preparation of channel variables
MemSegmentNum = 1;



% The end of evaluation and parameters preparation area !!!