% function PicoSetup
clc
if not(libisloaded('ps4000'))
loadlibrary('ps4000','ps4000Api.h')
end
clc
if not(libisloaded('ps4000wrap'))
loadlibrary('ps4000wrap','ps4000wrap.h')
end

pause(0.5)

%%
Count = int16(0);
Count_ptr = libpointer('int16Ptr',Count);
Serials = 'ups';
Serials_ptr = libpointer('stringPtr',Serials);
SerialLth = int16(0);
SerialLth_ptr = libpointer('int16Ptr',SerialLth);

[Status] = calllib('ps4000','ps4000EnumerateUnits',Count_ptr,Serials_ptr,SerialLth_ptr);

disp(num2str(Count));
disp(char(Serials));
pause(0.5)

%%
UnitHandle = int16(1);
[Status UnitHandle] = calllib('ps4000','ps4000OpenUnit',UnitHandle);
disp(strcat('OpenUnit=',num2str(Status)))
pause(1)

%%
String = '';
StringLength = int16(128);
RequiredSize = int16(0);
RequiredSize_Ptr = libpointer('int16Ptr',RequiredSize);
InfoCode = uint32(4);
[Status String RequiredSize] = calllib('ps4000','ps4000GetUnitInfo',UnitHandle,String,StringLength,RequiredSize_Ptr,InfoCode);
disp(strcat('GetUnitInfo=',num2str(Status)))
disp(strcat('PicoSerial=',String))

switch String
case 'ZOR15/051'
Osc1 = UnitHandle;
disp('Osc1 is found');
case 'ZOR15/065'
Osc2 = UnitHandle;
disp('Osc2 is found');
case 'ZOR15/026'
Osc3 = UnitHandle;
disp('Osc3 is found');
end
%%
Status = calllib('ps4000','ps4000FlashLed',Osc1,5);
disp(strcat('FlashLed=',num2str(Status)))
pause(0.5)

%%
% switching of all channel off
for k = 0:3
PS4000_Channel = uint16(k); % A-0, B-1, C-2, D-3
Enabled = int16(0); % 1-Yes, 2-No
Coupling = int16(1); % 1-DC, 0-AC;
VRange = 'ps4000_100MV';
Status = calllib('ps4000','ps4000SetChannel',Osc1,PS4000_Channel,Enabled,Coupling,VRange);
disp(strcat('CloseChannel_',num2str(PS4000_Channel),'=',num2str(Status)))
pause(0.25)
end

% switching of A channel on
PS4000_Channel = uint16(0); % A-0, B-1, C-2, D-3
Enabled = int16(1); % 1-Yes, 2-No
Coupling = int16(1); % 1-DC, 0-AC;
VRange = 'ps4000_100MV';
Status = calllib('ps4000','ps4000SetChannel',Osc1,PS4000_Channel,Enabled,Coupling,VRange);
disp(strcat('OpenChannel_',num2str(PS4000_Channel),'=',num2str(Status)))

% Saving of time/sample base settings
save('LastChanSettings.mat','PS4000_Channel','Enabled','Coupling',...
    'VRange');

% memory devision
NSegments = uint16(1);
nMaxSamples = int32(0);
nMaxSamples_ptr = libpointer('int32Ptr',nMaxSamples);
[Status nMaxSamples] = calllib('ps4000','ps4000MemorySegments',Osc1,NSegments,nMaxSamples);
disp(strcat('MemorySegments=',num2str(Status)))
%%
% time/sample base settings
TimeBase = uint32(0);
NSamples = int32(3000);
TimeInterval = single(2);
OverSamle = int16(1);
MaxSamples = int32(0);
MaxSamples = libpointer('int32Ptr',MaxSamples);
SegmentIndex = uint16(0);
[Status TimeInterval MaxSamples] = calllib('ps4000','ps4000GetTimebase2',Osc1,TimeBase,NSamples,TimeInterval,OverSamle,MaxSamples,SegmentIndex);
disp(strcat('GetTimebase=',num2str(Status)))

% Saving of time/sample base settings
save('LastTimeSettings.mat','TimeBase','NSamples','TimeInterval',...
    'OverSamle','MaxSamples','SegmentIndex');
%%
NoOfSamples = uint32(3355439);
PreTrigSampl = int32(0);
PostTrigSampl = int32(int32(NoOfSamples)-PreTrigSampl);
TimeBase = uint32(1);
OverSamle = int16(1);
TimeTot = int32(0);
TimeTot_ptr = libpointer('int32Ptr',TimeTot);
SegmentIndex = uint16(0);
FunctionRun = int32(0);
FunctionRun_ptr = libpointer('voidPtr');
Ready = int32(0);
Ready_ptr = libpointer('int16Ptr',Ready);
[Status] = calllib('ps4000wrap','RunBlock',Osc1,PreTrigSampl,PostTrigSampl,TimeBase,OverSamle,SegmentIndex);

Status
%%
disp(strcat('RecordReady=',num2str(get(Ready_ptr,'value'))));

while not(get(Ready_ptr,'value'))
pause(1);
disp(strcat('RecordReady=',num2str(get(Ready_ptr,'value'))));
end

%%

PS4000_Channel = uint16(0); % A-0, B-1, C-2, D-3
Buffer = zeros(NoOfSamples,1);
Buffer_ptr = libpointer('int16Ptr',Buffer);
BufferLth = NoOfSamples;
[Status] = calllib('ps4000','ps4000SetDataBuffer',Osc1,PS4000_Channel,Buffer_ptr,BufferLth);
disp(strcat('BufferAllocation=',num2str(Status),'(',num2str(BufferLth),'Samples)'));

StartIndex = uint32(0);
NoOfSamples_ptr = libpointer('uint32Ptr',NoOfSamples);
DownSampleRatio = uint32(0);
DownSampleRatioMode = int16(0);
SegmentIndex = uint16(0);
OverFlow = int16(20);
OverFlow_ptr = libpointer('int16Ptr',OverFlow);

[Status] = calllib('ps4000','ps4000GetValues',Osc1,StartIndex,NoOfSamples_ptr,DownSampleRatio,DownSampleRatioMode,SegmentIndex,OverFlow_ptr);
disp(strcat('GetValues=',num2str(Status)));

Data = get(Buffer_ptr,'value');
close all
figure;plot(Data);

%%
NoOfSamples = uint32(2);

PS4000_Channel = uint16(0); % A-0, B-1, C-2, D-3
Buffer = zeros(NoOfSamples, 1);
Buffer_ptr = libpointer('int16Ptr', Buffer);
BufferLth = NoOfSamples;
[Status] = calllib('ps4000', 'ps4000SetDataBuffer', Osc1, PS4000_Channel, Buffer_ptr, BufferLth);
disp(strcat('BufferAllocation=',num2str(Status),'(',num2str(BufferLth),'Samples)'));
%%
Status = calllib('ps4000','ps4000Stop',Osc1);
disp(strcat('Stopping=',num2str(Status)))
%%
SampleUnterval = uint32(2);
SampleUnterval_ptr = libpointer('uint32Ptr', SampleUnterval);
SampleUntervalTimeUnits = uint16(4);
MaxPreTrigSampl = int32(0);
MaxPostTrigSampl = int32(int32(NoOfSamples)-MaxPreTrigSampl);
AutoStop = int16(1);
downSampleRatio = uint32(1);
overviewBufferSize = uint32(NoOfSamples);
%%
% 'c'
% [Status] = calllib('ps4000', 'ps4000RunStreaming', Osc1, SampleUnterval_ptr, SampleUntervalTimeUnits,...
%     MaxPreTrigSampl, MaxPostTrigSampl, AutoStop, downSampleRatio, overviewBufferSize);
% disp(strcat('RunnigStream=',num2str(Status)))
% %%
% 
% StartIndex = uint32(0);
% NoOfSamples_ptr = libpointer('uint32Ptr', NoOfSamples);
% DownSampleRatio = uint32(0);
% DownSampleRatioMode = int16(0);
% SegmentIndex = uint16(0);
% Ready = int16(20);
% Ready_Ptr = libpointer('int16Ptr', Ready);
% [Status] = calllib('ps4000', 'ps4000GetStreamingLatestValues', Osc1, NULL, Ready);
% disp(strcat('GetStreamValues=', num2str(Status)));
% 
% disp(strcat('DataReady=',num2str(get(Ready_ptr, 'value'))));
% while not(get(Ready_ptr, 'value'))
% pause(1);
% disp(strcat('DataReady=',num2str(get(Ready_ptr, 'value'))));
% end
% get(Buffer_ptr,'value')
% Data = get(Buffer_ptr, 'value');
% close all
%%
'opa'
Status = calllib('ps4000','ps4000Stop',Osc1);
disp(strcat('Stopping=',num2str(Status)))
Status = calllib('ps4000','ps4000CloseUnit',Osc1);
disp(strcat('Closin=',num2str(Status)))
unloadlibrary('ps4000');
% end

% function Status=ps4000BlockReady(OscH,Status,Ready)
% Status = 'jest1'
% end